@@ -1,5 +1,6 @@
 #' Add or query subject of message.
 #'
+#' @inheritParams text
 #' @param msg A message object.
 #' @param subject A subject for the message.
 #'
@@ -14,10 +15,22 @@
 #'
 #' # Retrieve the subject for a message
 #' subject(msg)
-subject <- function(msg, subject = NULL){
+subject <- function(
+  msg,
+  subject = NULL,
+  interpolate = TRUE,
+  .open = "{{",
+  .close = "}}",
+  .envir = NULL
+){
   if (is.null(subject)) {
     msg$header$Subject
   } else {
+    if (is.null(.envir)) .envir = parent.frame()
+    else .envir = list2env(.envir)
+
+    if (interpolate) subject <- glue(subject, .open = .open, .close = .close, .envir = .envir)
+
     msg$header$Subject <- subject
     invisible(msg)
   }
