@@ -1,7 +1,7 @@
 test_that("attachment: set", {
   msg <- envelope() %>% attachment(TXTPATH)
 
-  expect_equal(msg$parts[[1]]$body, base64encode(TXTPATH, 76L, "\r\n"))
+  expect_equal(msg$parts[[1]]$content, base64encode(TXTPATH, 76L, "\r\n"))
 })
 
 test_that("attachment: specify CID", {
@@ -9,8 +9,8 @@ test_that("attachment: specify CID", {
 
   msg <- envelope() %>% attachment(PNGPATH, cid = cid)
 
-  expect_equal(msg$parts[[1]]$body, base64encode(PNGPATH, 76L, "\r\n"))
-  expect_equal(msg$parts[[1]]$header$cid, cid)
+  expect_equal(msg$parts[[1]]$content, base64encode(PNGPATH, 76L, "\r\n"))
+  expect_equal(msg$parts[[1]]$cid, cid)
 })
 
 test_that("attachment: number of files", {
